@@ -674,6 +674,7 @@ read_directory <- function(directory,
                           table = "gps_data",
                           timezone = "",
                           session_threshold = 2,
+                          smooth_elevation_gain = TRUE,
                           correct_distances = FALSE,
                           country = NULL,
                           mask = TRUE,
@@ -747,6 +748,7 @@ read_directory <- function(directory,
                                correct_distances = correct_distances,
                                country = country,
                                mask = mask,
+                               smooth_elevation_gain = smooth_elevation_gain,
                                from_distances = from_distances,
                                sport = sport,
                                lgap = lgap,
@@ -769,6 +771,7 @@ read_directory <- function(directory,
                                       timezone = timezone,
                                       session_threshold = session_threshold,
                                       correct_distances = correct_distances,
+                                      smooth_elevation_gain = smooth_elevation_gain,
                                       country = country,
                                       mask = mask,
                                       from_distances = from_distances,
